/**************************************************************************
*       cx6x85.h -- header file for cx5x86.c (obviously)
*       Edwin Lim <elim@dodo.eng.uci.edu> June 6 1996
*       
*       Most stuff you do not have to fiddle with.  Unless you want to.
*
**************************************************************************/


/**************************************************************************
*       Some important defines
**************************************************************************/
#define ADDRESS_PORT 0x22
#define DATA_PORT 0x23

/* I dunno if these are still needed.  Preferbly I can do away with them */

#define PCR0 0x20
#define CCR1 0xc1
#define CCR2 0xc2
#define CCR3 0xc3
#define SMAR 0xcd
#define CCR4 0xe8
#define PMR  0xf0
#define DIR0 0xfe
#define DIR1 0xff

/**************************************************************************
*       Some global variables
**************************************************************************/

/* These are for values pass from the the kernel, i.e., command lines */

static int verb = 0;
static int show_reg = 0;
static int use_def = 0;         /* default settings */

static int use_smi = -1;
static int smac = -1;
static int mmac = -1;
static int use_wbak = -1;
static int lock_nw = -1;
static int susp_hlt = -1;
static int wt1 = -1;
static int bwrt = -1;
static int use_susp = -1;
static int smi_lock = -1;
static int nmi_en = -1;
static int linbrst = -1;
static int smm_mode = -1;
static int mapen0 = -1;
static int mapen1 = -1;
static int mapen2 = -1;
static int mapen3 = -1;
static int iort0 = -1;
static int iort1 = -1;
static int iort2 = -1;
static int mem_byp = -1;
static int dte_en = -1;
static int fp_fast = -1;
static int cpuiden = -1;
static int clk0 = -1;
static int clk1 = -1;
static int clk2 = -1;
static int hlf_clk = -1;
static int perf0 = -1;
static int perf1 = -1;
static int perf2 = -1;
static int rstk_en = -1;
static int btb_en = -1;
static int loop_en = -1;
static int lsser = -1;

/*
   Here are some structs for those who still want to control the
   registers the old way.
*/

static char *pcr0 = "";
static char *ccr1 = "";
static char *ccr2 = "";
static char *ccr3 = "";
static char *smar = "";
static char *smar0 = "";
static char *smar1 = "";
static char *smar2 = "";
static char *ccr4 = "";
static char *pmr = "";
static char *dir0 = "";
static char *dir1 = "";

/* 
    Here are some structs to store the bits and registers association.
    I have made it such that future adaptation to the 6x86 can be made
    easily (I hope).
*/

struct cxreg_tag {
        const char *name;
        const unsigned char addr;
        char **set_to;
};

static struct cxreg_tag *cxreg;

static struct cxreg_tag cx5reg[] = {
	{"PCR0", 0x20},
	{"CCR1", 0xc1},
	{"CCR2", 0xc2},
	{"CCR3", 0xc3},
	{"SMAR", 0xcd},
	{"SMAR0", 0xcd},
	{"SMAR1", 0xce},
	{"SMAR2", 0xcf},
	{"CCR4", 0xe8},
	{"PMR", 0xf0},
	{"DIR0", 0xfe},
	{"DIR1", 0xff},
        {NULL,}
};


struct cxbit_tag {
        const char *bitname;
        const char *regname;
        const unsigned int bitnumber;
	int *set_to;
};

static struct cxbit_tag *cxbit;

static struct cxbit_tag cx5bit[] = {
        {"USE_SMI", "CCR1", 1},
        {"SMAC", "CCR1", 2},
        {"MMAC", "CCR1", 3},
        {"USE_WBAK", "CCR2", 1},
        {"LOCK_NW", "CCR2", 2},
        {"SUSP_HLT", "CCR2", 3},
        {"WT1", "CCR2", 4},
        {"BWRT", "CCR2", 6},
        {"USE_SUSP", "CCR2", 7},
        {"SMI_LOCK", "CCR3", 0},
        {"NMI_EN", "CCR3", 1},
        {"LINBRST", "CCR3", 2},
        {"SMM_MODE", "CCR3", 3},
        {"MAPEN0", "CCR3", 4},
        {"MAPEN1", "CCR3", 5},
        {"MAPEN2", "CCR3", 6},
        {"MAPEN3", "CCR3", 7},
        {"IORT0", "CCR4", 0},
        {"IORT1", "CCR4", 1},
        {"IORT2", "CCR4", 2},
        {"MEM_BYP", "CCR4", 3},
        {"DTE_EN", "CCR4", 4},
        {"FP_FAST", "CCR4", 5},
        {"CPUIDEN", "CCR4", 7},
        {"CLK0", "PMR", 0},
        {"CLK1", "PMR", 1},
        {"CLK2", "PMR", 2},
        {"HLF_CLK", "PMR", 2},
        {"PERF0", "PCR0", 0},
        {"PERF1", "PCR0", 1},
        {"PERF2", "PCR0", 2},
        {"RSTK_EN", "PCR0", 0},
        {"BTB_EN", "PCR0", 1},
        {"LOOP_EN", "PCR0", 2},
        {"LSSER", "PCR0", 7},
        {NULL}
};


/**************************************************************************
*       Prototypes
**************************************************************************/
static void setcxbit(const char *, int, int);
static void setcxreg(const char *, char *);
static void showcxreg(void);
static void cxdefaults(void);
extern void cleanup_module(void);
